@@ -11,7 +11,7 @@ See the GNU General Public License for more details.
 You should have received a copy of the GNU Affero General Public License along with 'atomes'.
 If not, see <https://www.gnu.org/licenses/>
 
-Copyright (C) 2022-2024 by CNRS and University of Strasbourg */
+Copyright (C) 2022-2025 by CNRS and University of Strasbourg */
 
 /*!
 * @file global.c
@@ -627,7 +627,7 @@ double string_to_double (gpointer string)
   double value = strtod ((char *)string, & endPtr);
   if (endPtr == (char *)string)
   {
-     g_print ("Error in string format: %s - value == %lf\n", endPtr, value);
+     g_print ("Error in string format: string = %s - value == %lf\n", endPtr, value);
   }
   return value;
 }
