@@ -11,7 +11,7 @@ See the GNU General Public License for more details.
 You should have received a copy of the GNU Affero General Public License along with 'atomes'.
 If not, see <https://www.gnu.org/licenses/>
 
-Copyright (C) 2022-2024 by CNRS and University of Strasbourg */
+Copyright (C) 2022-2025 by CNRS and University of Strasbourg */
 
 /*!
 * @file w_atoms.c
@@ -59,6 +59,7 @@ Copyright (C) 2022-2024 by CNRS and University of Strasbourg */
 #include "color_box.h"
 
 extern atom_search * allocate_atom_search (int proj, int action, int searchid, int tsize);
+extern void check_hidden_visible (project * this_proj);
 extern gchar * label_atpts (project * this_proj, glwin * view, int id);
 extern GtkWidget * labels_tab (glwin * view, int id);
 extern GtkWidget * selection_tab (atom_search * asearch, int nats);
@@ -280,6 +281,7 @@ G_MODULE_EXPORT void toggled_show_hide_atom (GtkToggleButton * but, gpointer dat
     }
   }
   this_proj -> modelgl -> anim -> last -> img -> show_atom[j][k] = show;
+  check_hidden_visible (this_proj);
   init_default_shaders (this_proj -> modelgl);
   update_menu_bar (this_proj -> modelgl);
 #else
